==> RecordLinkage_0.3-5.zip: RecordLinkage/doc/Supervised.R <==
###################################################
### chunk number 1: 
###################################################
#line 4 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
options(width=50)


###################################################
### chunk number 2: 
###################################################
#line 28 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
library(RecordLinkage)
library(xtable)


###################################################
### chunk number 3: 
###################################################
#line 37 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
data(RLdata500)
data(RLdata10000)
train_pairs=compare.dedup(RLdata10000, identity=identity.RLdata10000,
  n_match=500, n_non_match=500)

eval_pairs=compare.dedup(RLdata500,identity=identity.RLdata500)


###################################################
### chunk number 4: 
###################################################
#line 54 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
model_rpart=trainSupv(train_pairs, method="rpart")
model_bagging=trainSupv(train_pairs, method="bagging")
model_svm=trainSupv(train_pairs, method="svm")


###################################################
### chunk number 5: 
###################################################
#line 66 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
result_rpart=classifySupv(model_rpart, eval_pairs)
result_bagging=classifySupv(model_bagging, eval_pairs)
result_svm=classifySupv(model_svm, eval_pairs)


###################################################
### chunk number 6: 
###################################################
#line 75 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
texSummary(result_rpart)


###################################################
### chunk number 7: 
###################################################
#line 80 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
texSummary(result_bagging)


###################################################
### chunk number 8: 
###################################################
#line 85 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/Supervised.rnw"
texSummary(result_svm)

==> RecordLinkage_0.4-1.zip: RecordLinkage/doc/Supervised.R <==
### R code from vignette source 'Supervised.rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: Supervised.rnw:3-4
###################################################
options(width=50)


###################################################
### code chunk number 2: Supervised.rnw:27-29
###################################################
library(RecordLinkage)
library(xtable)


###################################################
### code chunk number 3: Supervised.rnw:36-42
###################################################
data(RLdata500)
data(RLdata10000)
train_pairs=compare.dedup(RLdata10000, identity=identity.RLdata10000,
  n_match=500, n_non_match=500)

eval_pairs=compare.dedup(RLdata500,identity=identity.RLdata500)


###################################################
### code chunk number 4: Supervised.rnw:53-56
###################################################
model_rpart=trainSupv(train_pairs, method="rpart")
model_bagging=trainSupv(train_pairs, method="bagging")
model_svm=trainSupv(train_pairs, method="svm")


###################################################
### code chunk number 5: Supervised.rnw:65-68
###################################################
result_rpart=classifySupv(model_rpart, eval_pairs)
result_bagging=classifySupv(model_bagging, eval_pairs)
result_svm=classifySupv(model_svm, eval_pairs)


###################################################
### code chunk number 6: Supervised.rnw:74-75
###################################################
texSummary(result_rpart)


###################################################
### code chunk number 7: Supervised.rnw:79-80
###################################################
texSummary(result_bagging)


###################################################
### code chunk number 8: Supervised.rnw:84-85
###################################################
texSummary(result_svm)
